summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToJNI.pm
diff options
context:
space:
mode:
Diffstat (limited to 'kalyptus/kalyptusCxxToJNI.pm')
-rw-r--r--kalyptus/kalyptusCxxToJNI.pm17
1 files changed, 7 insertions, 10 deletions
diff --git a/kalyptus/kalyptusCxxToJNI.pm b/kalyptus/kalyptusCxxToJNI.pm
index 7d57f377..332b44de 100644
--- a/kalyptus/kalyptusCxxToJNI.pm
+++ b/kalyptus/kalyptusCxxToJNI.pm
@@ -536,12 +536,12 @@ EOF
}
/** Prepend a '2' to a signal string and remove any spaces */
- public static String SIGNAL(String signal) {
+ public static String TQ_SIGNAL(String signal) {
return "2" + sqeezeOut(signal, ' ');
}
/** Prepend a '1' to a slot string and remove any spaces */
- public static String SLOT(String slot) {
+ public static String TQ_SLOT(String slot) {
return "1" + sqeezeOut(slot, ' ');
}
@@ -1836,7 +1836,6 @@ sub cplusplusToJava
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_MediaList\s*\*/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_OfferList\s*\*/
|| $cplusplusType =~ /TQMemArray<TQRect>/
- || $cplusplusType =~ /TQArray<TQRect>/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QCanvasItemList\s*\*/ ) {
return "ArrayList"
} elsif ( $cplusplusType =~ /uchar\s*\*/ ) {
@@ -2247,8 +2246,6 @@ sub jniToReturnValue($$$)
$returnCall .= "\treturn (jobject) QtSupport::arrayWithTQIconDragItemList(env, (TQValueList<TQIconDragItem>*) " . ($1 eq "\*" ? "" : "&") . "_qlist);\n";
} elsif ( $cplusplusType =~ /TQMemArray<TQRect>\s*([\*\&])?\s*$/ ) {
$returnCall .= "\treturn (jobject) QtSupport::arrayWithTQRectList(env, (TQMemArray<TQRect>*) " . ($1 eq "\*" ? "" : "&") . "_qlist);\n";
- } elsif ( $cplusplusType =~ /TQArray<TQRect>\s*([\*\&])?\s*$/ ) {
- $returnCall .= "\treturn (jobject) QtSupport::arrayWithTQRectList(env, (TQArray<TQRect>*) " . ($1 eq "\*" ? "" : "&") . "_qlist);\n";
}
} elsif ( $javaType =~ /String\[\]/ ) {
; # Do nothing, string arrays are ArrayLists as return values
@@ -2628,7 +2625,7 @@ sub preParseClass
|| ($name eq 'qt_cast')
|| ($name eq 'qt_property')
|| ($name eq 'staticMetaObject')
# Assume only Qt classes have tr() and trUtf8() in their Q_OBJECT macro
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'tr')
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'trUtf8')
|| $name eq 'trUtf8'
@@ -2835,7 +2832,7 @@ sub writeClassDoc
my @ancestor_nodes = ();
Iter::Ancestors( $node, $rootnode, undef, undef, sub {
my ( $ances, $name, $type, $template ) = @_;
- if ( $name ne "TQMemArray" and $name ne "TQArray" and $name ne "TQSqlFieldInfoList" ) {
+ if ( $name ne "TQMemArray" and $name ne "TQSqlFieldInfoList" ) {
push @ancestor_nodes, $ances;
push @ancestors, $name;
}
@@ -5476,9 +5473,9 @@ sub printJavadocComment($$$$)
$line =~ s/const char/String/g;
$line =~ s/const (\w+)\&/$1/g;
$line =~ s/bool/boolean/g;
- $line =~ s/SLOT\(\s*([^\)]*)\) ?\)/SLOT("$1)")/g;
- $line =~ s/SIGNAL\(\s*([^\)]*)\) ?\)/SIGNAL("$1)")/g;
- $line =~ s/Q_OBJECT\n//g;
+ $line =~ s/TQ_SLOT\(\s*([^\)]*)\) ?\)/TQ_SLOT("$1)")/g;
+ $line =~ s/TQ_SIGNAL\(\s*([^\)]*)\) ?\)/TQ_SIGNAL("$1)")/g;
+ $line =~ s/TQ_OBJECT\n//g;
$line =~ s/class\s+([\w]+)\s*:\s*public/public class $1 implements/g;
$line =~ s/public\s*(slots)?:\n/public /g;
$line =~ s/([^0-9"]\s*)\*(\s*[^0-9"-])/$1$2/g;
@@ -2628,7 +2625,7 @@ sub preParseClass
|| ($name eq 'qt_property')
|| ($name eq 'staticMetaObject')
- # Assume only Qt classes have tr() and trUtf8() in their Q_OBJECT macro
+ # Assume only Qt classes have tr() and trUtf8() in their TQ_OBJECT macro
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'tr')
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'trUtf8')